pub struct CheetahBuilder { /* private fields */ }Expand description
Append-heavy builder for constructing Cheetah string values.
CheetahBuilder keeps mutable construction separate from immutable
clone-cheap CheetahStr values and stable string values.
Implementations
Sourceimpl CheetahBuilder
impl CheetahBuilder
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates an empty builder with at least capacity bytes.
Sourcepub fn from_string(value: String) -> Self
pub fn from_string(value: String) -> Self
Creates a builder from existing owned storage.
Sourcepub fn reserve(&mut self, additional: usize)
pub fn reserve(&mut self, additional: usize)
Reserves capacity for at least additional more bytes.
Sourcepub fn finish_string(self) -> CheetahString
pub fn finish_string(self) -> CheetahString
Finishes into a mutable string value, preserving spare capacity when it is useful for subsequent mutation.
Sourcepub fn finish_str(self) -> CheetahStr
pub fn finish_str(self) -> CheetahStr
Finishes into an immutable clone-cheap string value.
Sourcepub fn into_string(self) -> String
pub fn into_string(self) -> String
Returns the owned String backing this builder.